local BLOODTRADER_NPCID = 115264
local BLOOD_ITEMID = 124124
local BLOOD_ITEMTEXTURE = GetItemIcon(BLOOD_ITEMID)

local function IsBloodTrader()
  local guid = UnitGUID("npc")
  if not guid then return end
  local _, _, _, _, _, npcid = strsplit("-", guid)
  if not npcid then return end
  if tonumber(npcid) ~= BLOODTRADER_NPCID then return end
  return true
end

-- Hook GetMerchantItemInfo but only when it's called from within
-- FrameXML/MerchantFrame.lua's MerchantItemButton_OnModifiedClick() function
-- This makes the UI think that the Blood Trader only sells stacks of 1 for
-- the purposes of allowing split stacks.
local oldGetMerchantItemInfo = GetMerchantItemInfo
GetMerchantItemInfo = function(index)
  -- ignore if not blood trader
  if not IsBloodTrader() then return oldGetMerchantItemInfo(index) end

  -- get original values
  local name, texture, price, quantity, numAvailable, isUsable, extendedCost = oldGetMerchantItemInfo(index)
  
  -- only change quantity if GetMerchantItemInfo is being called from MerchantItemButton_OnModifiedClick
  local stack = debugstack(2,1,1)
  if stack:match("MerchantItemButton_OnModifiedClick") then quantity = 1 end
  
  -- return values with quantity possibly modified
  return name, texture, price, quantity, numAvailable, isUsable, extendedCost  
end

hooksecurefunc("MerchantFrame_UpdateCurrencies", function ()
  -- ignore if not blood trader
  if not IsBloodTrader() then return end
  
  -- the following code mimics MerchantFrame_UpdateCurrencies in showing currencies in lower right
  -- except it assumes only 1 will be shown (instead of up to 6), and it uses Item functions instead
  -- of Currency functions
  MerchantExtraCurrencyInset:Show()
  MerchantExtraCurrencyBg:Show()
  MerchantMoneyFrame:SetPoint("BOTTOMRIGHT", -169, 8)
  MerchantMoneyFrame:Show()
  
  local tokenButton = _G["MerchantToken1"]
  -- if this button doesn't exist yet, create it and anchor it
  if ( not tokenButton ) then
    tokenButton = CreateFrame("BUTTON", "MerchantToken1", MerchantFrame, "BackpackTokenTemplate")
    tokenButton:SetPoint("BOTTOMRIGHT", -16, 8)
    tokenButton:SetScript("OnEnter", function(self) GameTooltip:SetOwner(self, "ANCHOR_RIGHT") GameTooltip:SetItemByID(BLOOD_ITEMID) end)
    tokenButton:SetScript("OnClick", function(self, button) if IsModifiedClick("CHATLINK") then HandleModifiedItemClick(select(2, GetItemInfo(BLOOD_ITEMID))) end end)
  end
  
  tokenButton.icon:SetTexture(BLOOD_ITEMTEXTURE)
  tokenButton.count:SetText(GetItemCount(BLOOD_ITEMID, true) or 0)
  tokenButton:Show();
end)
